//=============================================================================
// EquipSceneDrawRemoveText.js
// ----------------------------------------------------------------------------
// (C) 2019 astral
// This software is released under the MIT License.
// https://opensource.org/licenses/mit-license.php
// ----------------------------------------------------------------------------
// Version
// 1.0.1 2019/04/10 装備を外す表示条件を追加
// 1.0.0 2019/04/09 初版
/*:
 * 
 * @plugindesc 装備画面の装備一覧に、装備を外す表示を追加します
 * @author astral
 * 
 * @param display remove equip
 * @text 装備を外すコマンド名
 * @desc 装備一覧に装備を外す文字列を追加して表示します。
 * @type string
 * @default 装備を外す
 * 
 * @param icon index
 * @text アイコン番号
 * @desc 文字列の横に表示する0から始まるアイコン番号指定します。-1で非表示です。
 * @type number
 * @min -1
 * @default -1
 * 
 * @param move position to top
 * @text 先頭に表示する
 * @desc 装備を外すを装備選択一覧の先頭に表示します。
 * @type boolean
 * @default false
 * 
 * @help
 * 
 * 装備画面の装備一覧に、装備を外す表示を追加します
 * 
 * デフォルトでは空欄のものを選択すると装備が外れますが、
 * それを指定した文字列で選択出来るようにし、わかりやすいようにします。
 * 
 * 0から始まるアイコン番号も指定出来ます。
 * コマンドの文字列は空欄で、アイコン番号は-1でそれぞれが非表示になります。
 * 
 * パラメーターの先頭に表示するをon(true)にすると、
 * デフォルトの装備一覧の最後に表示されるものを、最初に表示するようにします。
 * 
 * 
 * 
 * MIT License.
 * 
 */


(function () {
    'use strict';

    var param = (function (parameters){
        var $ = JSON.parse(JSON.stringify(parameters, function(key, value) {
            try {
                return JSON.parse(value);
            } catch (e) {
                return value;
            }
        }));
        return {
            dispRemoveEquip: toString($['display remove equip']),
            dispIconIndex: toNumber($['icon index']),
            enableEquipRemoveTop:!!$['move position to top'],
        };
    })(PluginManager.parameters('EquipSceneDrawRemoveText'));


    var _Window_EquipItem_drawItem = Window_EquipItem.prototype.drawItem;
    Window_EquipItem.prototype.drawItem = function(index) {
        _Window_EquipItem_drawItem.apply(this, arguments);

        if (this._data[index] !== null) return;
        if (this._slotId < 0) return;
        var dispName = param.dispRemoveEquip;
        if (!dispName) return;
        var numberWidth = this.numberWidth();
        var rect = this.itemRect(index);
        rect.width -= this.textPadding();
        this.changePaintOpacity(1);
        this.drawItemName(null, rect.x, rect.y, rect.width - numberWidth);
        this.changePaintOpacity(1);
    };

    var _Window_EquipItem_makeItemList = Window_EquipItem.prototype.makeItemList;
    Window_EquipItem.prototype.makeItemList = function() {
        _Window_EquipItem_makeItemList.apply(this, arguments);
        if (!param.enableEquipRemoveTop) return;
        if (this._slotId < 0) return;
        if (this.includes(null)) {
            var lastIndex = (this._data.length || 1) - 1;
            if (this._data[lastIndex] === null) {
                this._data.length = lastIndex;
            }
            this._data.unshift(null);
        }
    };

    var _Window_EquipItem_drawItemName = Window_EquipItem.prototype.drawItemName;
    Window_EquipItem.prototype.drawItemName = function(item, x, y, width) {
        _Window_EquipItem_drawItemName.apply(this, arguments);

        if (item !== null) return;
        if (this._slotId < 0) return;
        var dispName = param.dispRemoveEquip;
        if (!dispName) return;
        width = width || 312;
        var iconBoxWidth = Window_Base._iconWidth + 4;
        this.resetTextColor();
        var iconIndex = param.dispIconIndex;
        if (iconIndex >= 0) this.drawIcon(iconIndex, x + 2, y + 2);
        this.drawText(dispName, x + iconBoxWidth, y, width - iconBoxWidth);
    };

    function isNumber(val) {return typeof val === 'number';};

    function toNumber(val) {
        return isNumber(val) ? val : parseInt(val) || 0;
    };

    function isString(val) {return typeof val === 'string';};
    
    function toString(val, d) {
        return isString(val) ? val : d || '';
    };

})();